ABlog v0.9 released
===================

.. post:: Feb 17, 2018
   :author: Nabil
   :category: Release
   :location: World

ABlog v0.9.0 is released with the main focus being to support the latest version of Sphinx.
This also moves the main development from `Abakan`_ to `SunPy`_.

This has merged in all current (at time of writing, 6) open PRs to the original repository.

These are:

`fix(commands): Update command arguments so patterns works correctly <https://github.com/abakan/ablog/pull/96>`__ from `rayalan <https://github.com/rayalan>`__.

`Fix couple of bugs with latest stable Sphinx <https://github.com/abakan/ablog/pull/93>`__ from `tadeboro <https://github.com/tadeboro>`__.

`don't use fancy quotes in the conf.py template <https://github.com/abakan/ablog/pull/87>`__ from `tiwo <https://github.com/tiwo>`__.

`Pass through additional Sphinx options and fix a typo <https://github.com/abakan/ablog/pull/84>`__ from `ahrbel <https://github.com/ahrbe1>`__.

`fix #78 (ImportError: cannot import name make_admonition in Sphinx 1.6) <https://github.com/abakan/ablog/pull/79>`_ from `lsaffre <https://github.com/lsaffre>`__.

`Raise exception when title is missing <https://github.com/abakan/ablog/pull/76>`__ from `rgrinberg <https://github.com/rgrinberg>`__.

.. _Abakan: https://github.com/abakan/ablog
.. _SunPy: https://github.com/sunpy/ablog

ABlog v0.9.1 released
---------------------

.. post:: March 2, 2018
   :author: Nabil
   :category: Release
   :location: World

Minor update to remove Ablog{}.format(python_number) exes

ABlog v0.9.2 released
---------------------

.. post:: March 4, 2018
   :author: Nabil
   :category: Release
   :location: World

Fixed Windows String issue.

ABlog v0.9.3 released
---------------------

.. post:: October 30, 2018
   :author: Nabil
   :category: Release
   :location: World

Added example on how to use writing blog posts in Jupyter notebooks.

`show </span> when if fa <https://github.com/sunpy/ablog/pull/22>`__, `Add create file encoding <https://github.com/sunpy/ablog/pull/23>`__ and `fix serve command path <https://github.com/sunpy/ablog/pull/31>`__ from `anzawatta <https://github.com/anzawatta>`__.

Sorry I was late to release these!

ABlog v0.9.4 released
---------------------

.. post:: Feb 10, 2019
   :author: Nabil
   :category: Release
   :location: World

Fixes for gettext break and some pathing issues.

ABlog v0.9.5 released
---------------------

.. post:: Aug 19, 2019
   :author: Nabil
   :category: Release
   :location: World

v0.9.5 is the that supports Python 2 and Sphinx <2.
v0.10.0 on main now, will not.

`Define an auto-orphan option <https://github.com/sunpy/ablog/pull/39>`__, `Repair update directive <https://github.com/sunpy/ablog/pull/37>`__ and `Fix sidebar and blog_baseurl misconfig during quick start <https://github.com/sunpy/ablog/pull/36>`__ from `rayalan <https://github.com/rayalan>`__.
